@@ -5,6 +5,7 @@ from collections import defaultdict
 import numpy as np
 
 from sdmetrics import single_table
+from sdmetrics.errors import IncomputableMetricError
 from sdmetrics.multi_table.base import MultiTableMetric
 from sdmetrics.utils import nested_attrs_meta
 
@@ -36,7 +37,7 @@ class MultiSingleTableMetric(MultiTableMetric, metaclass=nested_attrs_meta('sing
         self.single_table_metric = single_table_metric
         self.compute = self._compute
 
-    def _compute(self, real_data, synthetic_data, metadata=None):
+    def _compute(self, real_data, synthetic_data, metadata=None, **kwargs):
         """Compute this metric.
 
         This applies the underlying single table metric to all the tables
@@ -66,15 +67,27 @@ class MultiSingleTableMetric(MultiTableMetric, metaclass=nested_attrs_meta('sing
         elif not isinstance(metadata, dict):
             metadata = metadata.to_dict()
 
-        values = []
+        scores = {}
+        errors = {}
         for table_name, real_table in real_data.items():
             synthetic_table = synthetic_data[table_name]
             table_meta = metadata['tables'][table_name]
 
-            score = self.single_table_metric.compute(real_table, synthetic_table, table_meta)
-            values.append(score)
+            try:
+                score_breakdown = self.single_table_metric.compute_breakdown(
+                    real_table, synthetic_table, table_meta, **kwargs)
+                scores[table_name] = score_breakdown
+            except AttributeError:
+                score = self.single_table_metric.compute(
+                    real_table, synthetic_table, table_meta, **kwargs)
+                scores[table_name] = score
+            except Exception as error:
+                errors[table_name] = error
 
-        return np.nanmean(values)
+        if not scores:
+            raise IncomputableMetricError(f'Encountered the following errors: {errors}')
+
+        return scores
 
     @classmethod
     def compute(cls, real_data, synthetic_data, metadata=None, **kwargs):
@@ -99,6 +112,45 @@ class MultiSingleTableMetric(MultiTableMetric, metaclass=nested_attrs_meta('sing
             Union[float, tuple[float]]:
                 Metric output.
         """
+        scores = cls._compute(cls, real_data, synthetic_data, metadata, **kwargs)
+        scores = list(scores.values())
+        if len(scores) > 0 and isinstance(scores[0], dict):
+            all_scores = []
+            for table_scores in scores:
+                if 'score' in table_scores:
+                    all_scores.append(table_scores['score'])
+                else:
+                    all_scores.extend([
+                        result['score'] for result in table_scores.values() if 'score' in result
+                    ])
+
+            scores = all_scores
+
+        return np.nanmean(scores)
+
+    @classmethod
+    def compute_breakdown(cls, real_data, synthetic_data, metadata=None, **kwargs):
+        """Compute this metric broken down by tables and columns.
+
+        This applies the underlying single table metric to all the tables
+        found in the dataset and then returns the breakdown of the obtained scores.
+
+        Args:
+            real_data (dict[str, pandas.DataFrame]):
+                The tables from the real dataset.
+            synthetic_data (dict[str, pandas.DataFrame]):
+                The tables from the synthetic dataset.
+            metadata (dict):
+                Multi-table metadata dict. If not passed, it is build based on the
+                real_data fields and dtypes.
+            **kwargs:
+                Any additional keyword arguments will be passed down
+                to the single table metric
+
+        Returns:
+            dict[string -> dict[string -> Union[float, tuple[float]]]]:
+                A mapping of table name to column metric breakdowns.
+        """
         return cls._compute(cls, real_data, synthetic_data, metadata, **kwargs)
 
     @classmethod
@@ -123,16 +175,58 @@ class CSTest(MultiSingleTableMetric):
     single_table_metric = single_table.multi_single_column.CSTest
 
 
-class KSTest(MultiSingleTableMetric):
-    """MultiSingleTableMetric based on SingleTable KSTest."""
+class KSComplement(MultiSingleTableMetric):
+    """MultiSingleTableMetric based on SingleTable KSComplement."""
 
-    single_table_metric = single_table.multi_single_column.KSTest
+    single_table_metric = single_table.multi_single_column.KSComplement
 
 
-class KSTestExtended(MultiSingleTableMetric):
-    """MultiSingleTableMetric based on SingleTable KSTestExtended."""
+class StatisticSimilarity(MultiSingleTableMetric):
+    """MultiSingleTableMetric based on SingleTable StatisticSimilarity."""
 
-    single_table_metric = single_table.multi_single_column.KSTestExtended
+    single_table_metric = single_table.multi_single_column.StatisticSimilarity
+
+
+class BoundaryAdherence(MultiSingleTableMetric):
+    """MultiSingleTableMetric based on SingleTable BoundaryAdherence."""
+
+    single_table_metric = single_table.multi_single_column.BoundaryAdherence
+
+
+class MissingValueSimilarity(MultiSingleTableMetric):
+    """MultiSingleTableMetric based on SingleTable MissingValueSimilarity."""
+
+    single_table_metric = single_table.multi_single_column.MissingValueSimilarity
+
+
+class CategoryCoverage(MultiSingleTableMetric):
+    """MultiSingleTableMetric based on SingleTable CategoryCoverage."""
+
+    single_table_metric = single_table.multi_single_column.CategoryCoverage
+
+
+class TVComplement(MultiSingleTableMetric):
+    """MultiSingleTableMetric based on SingleTable TVComplement."""
+
+    single_table_metric = single_table.multi_single_column.TVComplement
+
+
+class RangeCoverage(MultiSingleTableMetric):
+    """MultiSingleTableMetric based on SingleTable RangeCoverage."""
+
+    single_table_metric = single_table.multi_single_column.RangeCoverage
+
+
+class CorrelationSimilarity(MultiSingleTableMetric):
+    """MultiSingleTableMetric based on SingleTable CorrelationSimilarity."""
+
+    single_table_metric = single_table.multi_column_pairs.CorrelationSimilarity
+
+
+class ContingencySimilarity(MultiSingleTableMetric):
+    """MultiSingleTableMetric based on SingleTable ContingencySimilarity."""
+
+    single_table_metric = single_table.multi_column_pairs.ContingencySimilarity
 
 
 class LogisticDetection(MultiSingleTableMetric):
@@ -153,6 +247,12 @@ class BNLikelihood(MultiSingleTableMetric):
     single_table_metric = single_table.bayesian_network.BNLikelihood
 
 
+class NewRowSynthesis(MultiSingleTableMetric):
+    """MultiSingleTableMetric based on SingleTable NewRowSynthesis."""
+
+    single_table_metric = single_table.new_row_synthesis.NewRowSynthesis
+
+
 class BNLogLikelihood(MultiSingleTableMetric):
     """MultiSingleTableMetric based on SingleTable BNLogLikelihood."""
 
