@@ -3,12 +3,13 @@
 import logging
 
 import numpy as np
-from rdt import HyperTransformer
 from sklearn.metrics import roc_auc_score
 from sklearn.model_selection import StratifiedKFold
 
+from sdmetrics.errors import IncomputableMetricError
 from sdmetrics.goal import Goal
 from sdmetrics.single_table.base import SingleTableMetric
+from sdmetrics.utils import HyperTransformer
 
 LOGGER = logging.getLogger(__name__)
 
@@ -64,13 +65,24 @@ class DetectionMetric(SingleTableMetric):
             float:
                 One minus the ROC AUC Cross Validation Score obtained by the classifier.
         """
-        metadata = cls._validate_inputs(real_data, synthetic_data, metadata)
-        transformer = HyperTransformer(default_data_type_transformers={'O': 'one_hot_encoding'})
-        real_data = transformer.fit_transform(real_data).to_numpy()
-        synthetic_data = transformer.transform(synthetic_data).to_numpy()
+        real_data, synthetic_data, metadata = cls._validate_inputs(
+            real_data, synthetic_data, metadata)
 
-        X = np.concatenate([real_data, synthetic_data])
-        y = np.hstack([np.ones(len(real_data)), np.zeros(len(synthetic_data))])
+        if metadata is not None and 'primary_key' in metadata:
+            transformed_real_data = real_data.drop(metadata['primary_key'], axis=1)
+            transformed_synthetic_data = synthetic_data.drop(metadata['primary_key'], axis=1)
+
+        else:
+            transformed_real_data = real_data
+            transformed_synthetic_data = synthetic_data
+
+        ht = HyperTransformer()
+        transformed_real_data = ht.fit_transform(transformed_real_data).to_numpy()
+        transformed_synthetic_data = ht.transform(transformed_synthetic_data).to_numpy()
+        X = np.concatenate([transformed_real_data, transformed_synthetic_data])
+        y = np.hstack([
+            np.ones(len(transformed_real_data)), np.zeros(len(transformed_synthetic_data))
+        ])
         if np.isin(X, [np.inf, -np.inf]).any():
             X[np.isin(X, [np.inf, -np.inf])] = np.nan
 
@@ -85,8 +97,7 @@ class DetectionMetric(SingleTableMetric):
 
             return 1 - np.mean(scores)
         except ValueError as err:
-            LOGGER.info('DetectionMetric: Skipping due to %s', err)
-            return np.nan
+            raise IncomputableMetricError(f'DetectionMetric: Unable to be fit with error {err}')
 
     @classmethod
     def normalize(cls, raw_score):
