@@ -6,6 +6,7 @@ import numpy as np
 from sdmetrics.goal import Goal
 from sdmetrics.single_table.base import SingleTableMetric
 from sdmetrics.single_table.privacy.loss import InverseCDFDistance
+from sdmetrics.utils import get_columns_from_metadata
 
 
 class CategoricalType(Enum):
@@ -62,7 +63,8 @@ class CategoricalPrivacyMetric(SingleTableMetric):
 
     @classmethod
     def _validate_inputs(cls, real_data, synthetic_data, metadata, key_fields, sensitive_fields):
-        metadata = super()._validate_inputs(real_data, synthetic_data, metadata)
+        real_data, synthetic_data, metadata = super()._validate_inputs(
+            real_data, synthetic_data, metadata)
         if 'key_fields' in metadata:
             key_fields = metadata['key_fields']
         elif key_fields is None:
@@ -74,6 +76,9 @@ class CategoricalPrivacyMetric(SingleTableMetric):
             raise TypeError(
                 '`sensitive_fields` must be passed either directly or inside `metadata`')
 
+        if len(key_fields) == 0 or len(sensitive_fields) == 0:
+            raise ValueError('`key_fields` or `sensitive_fields` is empty')
+
         return key_fields, sensitive_fields, metadata
 
     @classmethod
@@ -120,15 +125,12 @@ class CategoricalPrivacyMetric(SingleTableMetric):
             sensitive_fields
         )
 
-        if len(key_fields) == 0 or len(sensitive_fields) == 0:
-            return np.nan
-
         for col in key_fields + sensitive_fields:
-            data_type = metadata['fields'][col]
+            data_type = get_columns_from_metadata(metadata)[col]
             if (data_type != cls._DTYPES_TO_TYPES['i']
                and data_type != cls._DTYPES_TO_TYPES['O']
                and data_type != cls._DTYPES_TO_TYPES['b']):  # check data type
-                return np.nan
+                raise TypeError(f'Column {col} has invalid data type {data_type}')
 
         model = cls._fit(synthetic_data, key_fields, sensitive_fields, model_kwargs)
 
@@ -208,7 +210,8 @@ class NumericalPrivacyMetric(SingleTableMetric):
 
     @classmethod
     def _validate_inputs(cls, real_data, synthetic_data, metadata, key_fields, sensitive_fields):
-        metadata = super()._validate_inputs(real_data, synthetic_data, metadata)
+        real_data, synthetic_data, metadata = super()._validate_inputs(
+            real_data, synthetic_data, metadata)
         if 'key_fields' in metadata:
             key_fields = metadata['key_fields']
         elif key_fields is None:
@@ -220,6 +223,9 @@ class NumericalPrivacyMetric(SingleTableMetric):
             raise TypeError(
                 '`sensitive_fields` must be passed either directly or inside `metadata`')
 
+        if len(key_fields) == 0 or len(sensitive_fields) == 0:
+            raise ValueError('`key_fields` or `sensitive_fields` is empty')
+
         return key_fields, sensitive_fields, metadata
 
     @classmethod
@@ -268,15 +274,12 @@ class NumericalPrivacyMetric(SingleTableMetric):
             cls._validate_inputs(real_data, synthetic_data, metadata, key_fields, sensitive_fields)
         )
 
-        if len(key_fields) == 0 or len(sensitive_fields) == 0:
-            return np.nan
-
         for col in key_fields + sensitive_fields:
-            data_type = metadata['fields'][col]
+            data_type = get_columns_from_metadata(metadata)[col]
 
             # check data type
             if data_type != cls._DTYPES_TO_TYPES['i'] and data_type != cls._DTYPES_TO_TYPES['f']:
-                return np.nan
+                raise TypeError(f'Column {col} has invalid data type {data_type}')
 
         model = cls._fit(synthetic_data, key_fields, sensitive_fields, model_kwargs)
 
