@@ -2,11 +2,10 @@
 
 from sdmetrics.timeseries.efficacy.base import TimeSeriesEfficacyMetric
 from sdmetrics.timeseries.efficacy.classification import (
-    LSTMClassifierEfficacy, TimeSeriesClassificationEfficacyMetric, TSFClassifierEfficacy)
+    LSTMClassifierEfficacy, TimeSeriesClassificationEfficacyMetric)
 
 __all__ = [
     'TimeSeriesEfficacyMetric',
     'TimeSeriesClassificationEfficacyMetric',
     'LSTMClassifierEfficacy',
-    'TSFClassifierEfficacy',
 ]
